fermi2D — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# fermi2D

pyprocar.scripts.fermi2D(code: str, dirname: str, mode: str = 'plain', fermi: float | None = None, fermi_shift: float = 0.0, band_indices: List[List] | None = None, band_colors: List[List] | None = None, spins: List[int] | None = None, atoms: List[int] | None = None, orbitals: List[int] | None = None, energy: float | None = None, k_z_plane: float = 0.0, k_z_plane_tol: float = 0.01, rot_symm=1, translate: List[int] = [0, 0, 0], rotation: List[int] = [0, 0, 0, 1], spin_texture: bool = False, exportplt: bool = False, savefig: str | None = None, print_plot_opts: bool = False, **kwargs)

  This function plots the 2d fermi surface in the z = 0 plane

  Parameters:

    - code (str,) – This parameter sets the code to parse, by default “vasp”

    - dirname (str, optional) – This parameter is the directory of the calculation, by default ‘’

    - fermi (float, optional) – The fermi energy. If none is given, the fermi energy in the directory will be used, by default None

    - fermi_shift (float, optional) – The fermi energy shift, by default 0.0

    - lobster (bool, optional) – A boolean value to determine to use lobster, by default False

    - band_indices (List[List]) – A list of list that contains band indices for a given spin

    - band_colors (List[List]) – A list of list that contains colors for the band index corresponding the band_indices for a given spin

    - spins (List[int], optional) – List of spins, by default [0]

    - atoms (List[int], optional) – List of atoms, by default None

    - orbitals (List[int], optional) – List of orbitals, by default None

    - energy (float, optional) – The energy to generate the iso surface. When energy is None the 0 is used by default, which is the fermi energy, by default None

    - k_z_plane (float, optional) – Which K_z plane to generate 2d fermi surface, by default 0.0

    - rot_symm (int, optional) – _description_, by default 1

    - translate (List[int], optional) – Matrix to translate the kpoints, by default [0, 0, 0]

    - rotation (List[int], optional) – Matrix to rotate the kpoints, by default [0, 0, 0, 1]

    - savefig (str, optional) – The filename to save the plot as., by default None

    - spin_texture (bool, optional) – Boolean value to determine if spin arrows are plotted, by default False

    - exportplt (bool, optional) – Boolean value where to return the matplotlib.pyplot state plt, by default False

    - print_plot_opts (bool, optional) – Boolean to print the plotting options

  Returns:

    matplotlib.pyplot – Returns the matplotlib.pyplot state plt

  Raises:

    RuntimeError – invalid option –translate